##############################################################################
##################### qmake tunables for qosmic application ##################

## Installation prefix on *nix/osx
PREFIX = /usr

## The translations are installed in SHARED/translations.
## Icons are installed in SHARED/icons.
SHARED = $$PREFIX/share

## Default number of pthreads to use in libflam3
THREADS = 2

## Add your non-english locale here to install the translations.
## Only a naive set of french translations is available.
#CONFIG += ts_fr

## Uncomment to install qosmic application icons
CONFIG += install_icons

## Add search paths for headers and libraries here using either pkg-config to
## find the include paths,
CONFIG += link_pkgconfig
PKGCONFIG = flam3 lua

## The directory that contains flam3-palettes.xml must be set here.  If your
## system has pkg-config this should find the palettes.
FLAM3_PALETTES = $$system(pkg-config --variable=datarootdir flam3)/flam3

### or uncomment these to set the paths by hand
#INCLUDEPATH += /usr/include/libxml2
#LIBS += -L/usr/lib/libxml2 -lflam3 -lm -ljpeg -lxml2 -llua

## Build style flags.  Adding debug enables more verbose logging.
CONFIG += release warn_off
#CONFIG += debug warn_on
#CONFIG += debug warn_off

### set cflags here if needed ###
#QMAKE_CFLAGS="-march=nocona -m64 -O2 -pipe"
#QMAKE_CXXFLAGS=$$QMAKE_CFLAGS

##############################################################################

VERSION = 1.4.4
DEFINES += NTHREADS=$$THREADS
DEFINES += NAMEVER='\'"version $$VERSION"\''
DEFINES += FLAM3DIR='\'"$$FLAM3_PALETTES"\''
DEFINES += SHAREDIR='\'"$$SHARED"\''
CONFIG += qt thread
RESOURCES = qosmic.qrc
INCLUDEPATH += src
DESTDIR = .

## add the target to the install set
target.path += $$PREFIX/bin
INSTALLS += target

## add the translations to the install set
ts_fr {
	translations.files= ts/*.qm
	translations.path = $$SHARED/translations
	INSTALLS += translations
}

## add icons to the install set
install_icons {
	icons.files = icons/qosmicicon.xpm
	icons.path = $$SHARED/pixmaps
	INSTALLS += icons
}


! exists($$FLAM3_PALETTES/flam3-palettes.xml) {
	error("The file $$FLAM3_PALETTES/flam3-palettes.xml doesn't exist. "\
	"Please install libflam3 (http://flam3.org/) and set FLAM3_PALETTES"\
	"to the directory containing flam3-palettes.xml in qosmic.pro.")
}

message(Generating Makefile for Qosmic version $$VERSION)
message(Qt version : $$[QT_VERSION])
message(Default number of rendering threads : $$THREADS)
message(Location of flam3-palettes.xml : $$FLAM3_PALETTES)
! CONFIG(link_pkgconfig) {
	message(Include header paths : $$INCLUDEPATH)
	message(Include libraries : $$LIBS)
}

CONFIG(debug, debug|release) {
	## enable more verbose logging
	message(Building debug version)
	DEFINES += LOGGING
}

FORMS += \
 ui/mainwindow.ui \
 ui/mainviewer.ui \
 ui/paletteeditor.ui \
 ui/camerasettingswidget.ui \
 ui/colorsettingswidget.ui \
 ui/edittrianglewidget.ui \
 ui/imgsettingswidget.ui \
 ui/mainpreviewwidget.ui \
 ui/trianglecoordswidget.ui \
 ui/triangledensitywidget.ui \
 ui/variationswidget.ui \
 ui/mutationwidget.ui \
 ui/colorbalancewidget.ui \
 ui/directoryviewwidget.ui \
 ui/statuswidget.ui \
 ui/scripteditwidget.ui \
 ui/colordialog.ui \
 ui/selectgenomewidget.ui \
 ui/viewerpresetswidget.ui \
 ui/selecttrianglewidget.ui \
 ui/renderdialog.ui

HEADERS += \
 src/qosmic.h \
 src/flam3util.h \
 src/mainwindow.h \
 src/xfedit.h \
 src/basistriangle.h \
 src/triangle.h \
 src/nodeitem.h \
 src/mainviewer.h \
 src/renderthread.h \
 src/colorselector.h \
 src/genomecolorselector.h \
 src/paletteeditor.h \
 src/mutationwidget.h \
 src/previewwidget.h \
 src/colorlabel.h \
 src/doublevalueeditor.h \
 src/intvalueeditor.h \
 src/camerasettingswidget.h \
 src/colorsettingswidget.h \
 src/imgsettingswidget.h \
 src/mainpreviewwidget.h \
 src/trianglecoordswidget.h \
 src/variationswidget.h \
 src/logger.h \
 src/mutation.h \
 src/colorbalancewidget.h \
 src/gradientlistmodel.h \
 src/varstablewidget.h \
 src/directoryviewwidget.h \
 src/flamfileiconprovider.h \
 src/directorylistview.h \
 src/snapslider.h \
 src/statuswidget.h \
 src/edittrianglewidget.h \
 src/scripteditwidget.h \
 src/wheelvalueeditor.h \
 src/genomevector.h \
 src/lua/lunar.h \
 src/lua/frame.h \
 src/lua/xform.h \
 src/lua/genome.h \
 src/lua/luathread.h \
 src/colordialog.h \
 src/selectgenomewidget.h \
 src/viewerpresetswidget.h \
 src/coordinatemark.h \
 src/lua/mainwindowadapter.h \
 src/lua/highlighter.h \
 src/lua/luaeditor.h \
 src/lua/luatype.h \
 src/selecttrianglewidget.h \
 src/triangledensitywidget.h \
 src/undoring.h \
 src/trianglesubset.h \
 src/posttriangle.h \
 src/qosmicwidget.h \
 src/renderdialog.h

SOURCES += \
 src/qosmic.cpp \
 src/mainwindow.cpp \
 src/xfedit.cpp \
 src/basistriangle.cpp \
 src/triangle.cpp \
 src/nodeitem.cpp \
 src/flam3util.cpp \
 src/mainviewer.cpp \
 src/renderthread.cpp \
 src/colorselector.cpp \
 src/genomecolorselector.cpp \
 src/paletteeditor.cpp \
 src/logger.cpp \
 src/mutationwidget.cpp \
 src/colorlabel.cpp \
 src/doublevalueeditor.cpp \
 src/intvalueeditor.cpp \
 src/camerasettingswidget.cpp \
 src/colorsettingswidget.cpp \
 src/imgsettingswidget.cpp \
 src/mainpreviewwidget.cpp \
 src/trianglecoordswidget.cpp \
 src/variationswidget.cpp \
 src/previewwidget.cpp \
 src/mutation.c \
 src/colorbalancewidget.cpp \
 src/gradientlistmodel.cpp \
 src/varstablewidget.cpp \
 src/directoryviewwidget.cpp \
 src/flamfileiconprovider.cpp \
 src/directorylistview.cpp \
 src/snapslider.cpp \
 src/edittrianglewidget.cpp \
 src/statuswidget.cpp \
 src/scripteditwidget.cpp \
 src/wheelvalueeditor.cpp \
 src/lua/frame.cpp \
 src/lua/genome.cpp \
 src/lua/xform.cpp \
 src/lua/luathread.cpp \
 src/colordialog.cpp \
 src/selectgenomewidget.cpp \
 src/genomevector.cpp \
 src/viewerpresetswidget.cpp \
 src/coordinatemark.cpp \
 src/lua/mainwindowadapter.cpp \
 src/lua/highlighter.cpp \
 src/lua/luaeditor.cpp \
 src/lua/luatype.cpp \
 src/selecttrianglewidget.cpp \
 src/triangledensitywidget.cpp \
 src/undoring.cpp \
 src/trianglesubset.cpp \
 src/posttriangle.cpp \
 src/qosmicwidget.cpp \
 src/renderdialog.cpp

TRANSLATIONS = ts/qosmic_fr.ts

MOC_DIR = .moc
OBJECTS_DIR = .obj
RCC_DIR = .res
UI_DIR = .ui

